package com.ruoyi.tcZz.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.tcZz.domain.TcFb;
import com.ruoyi.tcZz.domain.TcWljg;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tcZz.domain.TcFbqk;
import com.ruoyi.tcZz.service.ITcFbqkService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;
import org.springframework.web.multipart.MultipartFile;

/**
 * 分布情况 tc_fbqkController
 * 
 * @author ruoyi
 * @date 2023-10-12
 */
@RestController
@Api(tags = "分布情况")
@RequestMapping("/tcZz/networkSecurity/fbqk")
public class TcFbqkController extends BaseController
{
    @Autowired
    private ITcFbqkService tcFbqkService;

    /**
     * 查询分布情况 tc_fbqk列表
     */
    @ApiOperation(value = "查询分布情况列表",response = TcFbqk.class)
    @GetMapping("/list")
    public TableDataInfo list(TcFbqk tcFbqk)
    {
        startPage();
        List<TcFbqk> list = tcFbqkService.selectTcFbqkList(tcFbqk);
        return getDataTable(list);
    }

    /**
     * 导出分布情况 tc_fbqk列表
     */
    @ApiOperation(value = "导出分布情况列表")
    @PostMapping("/export")
    public void export(HttpServletResponse response, TcFbqk tcFbqk)
    {
        List<TcFbqk> list = tcFbqkService.selectTcFbqkList(tcFbqk);
        ExcelUtil<TcFbqk> util = new ExcelUtil<TcFbqk>(TcFbqk.class);
        util.exportExcel(response, list, "分布情况 tc_fbqk数据");
    }

    /**
     * 获取分布情况 tc_fbqk详细信息
     */
    @ApiOperation(value = "获取分布情况详细信息")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcFbqkService.selectTcFbqkById(id));
    }

    /**
     * 新增分布情况 tc_fbqk
     */
    @ApiOperation(value = "新增分布情况")
    @PostMapping
    public AjaxResult add(@RequestBody TcFbqk tcFbqk)
    {
        return toAjax(tcFbqkService.insertTcFbqk(tcFbqk));
    }

    /**
     * 修改分布情况 tc_fbqk
     */
    @ApiOperation(value = "修改分布情况")
    @PutMapping
    public AjaxResult edit(@RequestBody TcFbqk tcFbqk)
    {
        return toAjax(tcFbqkService.updateTcFbqk(tcFbqk));
    }

    /**
     * 删除分布情况 tc_fbqk
     */
    @ApiOperation(value = "删除分布情况")
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcFbqkService.deleteTcFbqkByIds(ids));
    }


    /**
     * 导入
     */
    @ApiOperation("通用导入excel信息")
    @PostMapping("/common/importExcel")
    public AjaxResult importExcel(MultipartFile file) throws Exception {
        ExcelUtil<TcFbqk> util = new ExcelUtil<TcFbqk>(TcFbqk.class);
        List<TcFbqk> tcFbqkList = util.importExcel(file.getInputStream());
        tcFbqkService.importUser(tcFbqkList);
        return AjaxResult.success();
    }

    /**
     * 批量启用禁用
     *
     * @param isStatus 启用禁用状态
     * @return
     */

    @ApiOperation("批量启用禁用")
    @GetMapping("/isStatus")
    public AjaxResult isStatus(@RequestParam("isStatus") Integer isStatus, @RequestParam("ids") List<String> ids) {
        tcFbqkService.updateByisStatus(isStatus,ids);
        return AjaxResult.success();
    }

    @ApiOperation("通用下载excel模板")
    @PostMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response)
    {
        ExcelUtil<TcFbqk> util = new ExcelUtil<TcFbqk>(TcFbqk.class);
        util.importTemplateExcel(response, " 分布情况");
    }
}
